# weppy-BS3

weppy-BS3 is an extension for [weppy framework](http://weppy.org) providing Bootstrap3 UI elements.

## Installation

You can install weppy-BS3 using pip:

    pip install weppy-BS3

And add it to your weppy application:

```python
from weppy_bs3 import BS3

app.use_extension(BS3)
```

## Documentation

The complete documentation is available on the [weppy extensions registry](http://weppy.org/extensions/bs3).

## License

weppy-BS3 is released under BSD license. Check the LICENSE file for more details.
